.. _manifests:

Manifests
=========

The ASDF tags (described by schemas) available under each ASDF coordinates schemas versions are all described
by a single manifest document for that version.

.. asdf-autoschemas::
   :standard_prefix: manifests

   coordinates-1.0.0
